PopError

Enum PopError 

pub enum PopError {
    Empty,
    Closed,
    Timeout,
}
Error occurring when popping from a queue is unsuccessful.

Variants



Empty

The queue is empty.



Closed

All senders have been dropped and the queue is empty.



Timeout