Module future
Source - block_on
- event
- An efficient async condition variable for lock-free algorithms, a.k.a.
“eventcount”.
- waker
- Async, fast synchronization primitives for task wakeup.
- CatchUnwind
- Future for the
FutureExt::catch_unwind() method. - Fuse
Future for the fuse method.- Or
- Future for the
or() function and the FutureExt::or() method. - Pending
- Creates a future which never resolves, representing a computation that never
finishes.
- PollFn
- Future for the
poll_fn() function. - PollOnce
- Future for the
poll_once() function. - Race
- Future for the
race() function and the FutureExt::race() method. - Ready
- A future that is immediately ready with a value.
- TryZip
- Future for the
try_zip() function. - YieldNow
- Future for the
yield_now() function. - Zip
- Future for the
zip() function.
- Future
- A future represents an asynchronous computation, commonly obtained by use of
async. - FutureExt
- Extension trait for
Future.
- block_on
- Blocks the current thread on a future.
- fuse
- Fuse a future such that
poll will never again be called once it has
completed. This method can be used to turn any Future into a
FusedFuture. - or
- Returns the result of the future that completes first, preferring
future1 if both are ready. - pending
- Creates a future which never resolves, representing a computation that never
finishes.
- poll_fn
- Creates a future from a function returning
Poll. - poll_once
- Polls a future just once and returns an
Option with the result. - race
- Returns the result of the future that completes first, with no preference if both are ready.
- race_with_seed
- Race two futures but with a predefined random seed.
- ready
- Creates a future that is immediately ready with a value.
- try_zip
- Joins two fallible futures, waiting for both to complete or one of them to error.
- yield_now
- Wakes the current task and returns
Poll::Pending once. - zip
- Joins two futures, waiting for both to complete.
- Boxed
- Type alias for
Pin<Box<dyn Future<Output = T> + Send + 'static>>. - BoxedLocal
- Type alias for
Pin<Box<dyn Future<Output = T> + 'static>>.