Gn

Struct Gn 

pub struct Gn<A = ()> { /* private fields */ }
Generator helper

Implementations

Source

impl<A> Gn<A>

pub fn new_scoped<'a, T, F>(f: F) -> Generator<'a, A, T>
where for<'scope> F: FnOnce(Scope<'scope, 'a, A, T>) -> T + Send + 'a, T: Send + 'a, A: Send + 'a,

create a scoped generator with default stack size

pub fn new_scoped_local<'a, T, F>(f: F) -> LocalGenerator<'a, A, T>
where F: FnOnce(Scope<'_, '_, A, T>) -> T + 'a, T: 'a, A: 'a,

create a scoped local generator with default stack size

pub fn new_scoped_opt<'a, T, F>(size: usize, f: F) -> Generator<'a, A, T>
where for<'scope> F: FnOnce(Scope<'scope, 'a, A, T>) -> T + Send + 'a, T: Send + 'a, A: Send + 'a,

create a scoped generator with specified stack size

pub fn new_scoped_opt_local<'a, T, F>( size: usize, f: F, ) -> LocalGenerator<'a, A, T>
where F: FnOnce(Scope<'_, '_, A, T>) -> T + 'a, T: 'a, A: 'a,

create a scoped local generator with specified stack size

Source

impl<A: Any> Gn<A>

pub fn new<'a, T: Any, F>(f: F) -> Generator<'a, A, T>
where F: FnOnce() -> T + Send + 'a,

👎Deprecated since 0.6.18: please use scope version instead

create a new generator with default stack size

pub fn new_opt<'a, T: Any, F>(size: usize, f: F) -> Generator<'a, A, T>
where F: FnOnce() -> T + Send + 'a,

create a new generator with specified stack size