pub enum SpawnError {
Closed,
NoCapacity,
AttachFailed,
}Expand description
Errors that can occur when spawning a new task into the arena.
Variants
Closed
The arena is closed and no longer accepts new tasks.
NoCapacity
All task slots are currently in use.
AttachFailed
The reserved task slot already had an attached future.