Module worker

Module worker 

Structs

TimerBatch
Batch of scheduling requests.
TimerSchedule
Remote scheduling request for a timer.
WaitStrategy
WakeStats
Worker
WorkerHealthSnapshot
Health snapshot of a worker at a point in time. Used by the supervisor for health monitoring and load balancing decisions.
WorkerService
WorkerServiceConfig
WorkerStats
Comprehensive statistics for fast worker.
WorkerTLS

Enums

WorkerMessage
Worker control-plane messages.

Functions

cancel_timer_for_current_task
Cancels a timer owned by the task currently being polled by the active worker.
current_task
current_timer_wheel
current_worker_now_ns
Returns the most recent now_ns observed by the active worker.
is_worker_thread
pin_current_generator
Request that the current generator be pinned to the current task.
schedule_timer_for_current_task
Schedules a timer for the task currently being polled by the active worker.