pub struct WorkerHealthSnapshot {
pub worker_id: u32,
pub timestamp_ns: u64,
pub stats: WorkerStats,
pub yield_queue_len: usize,
pub mpsc_queue_len: usize,
pub active_leaf_partitions: Vec<usize>,
pub has_work: bool,
}Expand description
Health snapshot of a worker at a point in time. Used by the supervisor for health monitoring and load balancing decisions.
Fields
worker_id: u32timestamp_ns: u64stats: WorkerStatsyield_queue_len: usizempsc_queue_len: usizeactive_leaf_partitions: Vec<usize>has_work: boolTrait Implementations
Sourceimpl Clone for WorkerHealthSnapshot
impl Clone for WorkerHealthSnapshot
Sourcefn clone(&self) -> WorkerHealthSnapshot
fn clone(&self) -> WorkerHealthSnapshot
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreAuto Trait Implementations
impl Freeze for WorkerHealthSnapshot
impl RefUnwindSafe for WorkerHealthSnapshot
impl Send for WorkerHealthSnapshot
impl Sync for WorkerHealthSnapshot
impl Unpin for WorkerHealthSnapshot
impl UnwindSafe for WorkerHealthSnapshot