BlockingUnboundedSpscConsumer

Struct BlockingUnboundedSpscConsumer 

pub struct BlockingUnboundedSpscConsumer<T, const P: usize, const NUM_SEGS_P2: usize> { /* private fields */ }
Blocking consumer for unbounded SPSC queue.

Implementations

Source

impl<T, const P: usize, const NUM_SEGS_P2: usize> BlockingUnboundedSpscConsumer<T, P, NUM_SEGS_P2>

pub fn try_recv(&self) -> Result<T, PopError>

Fast-path receive without blocking.

pub fn recv(&self) -> Result<T, PopError>

Blocking receive that parks the thread until an item is available.

pub fn recv_batch(&self, dst: &mut [T]) -> Result<usize, PopError>
where T: Clone,

Blocking receive of multiple items.

pub fn node_count(&self) -> usize

Returns the number of nodes in the unbounded queue.

pub fn total_capacity(&self) -> usize

Returns the total capacity across all nodes.