BlockingUnboundedSpscProducer

Struct BlockingUnboundedSpscProducer 

pub struct BlockingUnboundedSpscProducer<T, const P: usize, const NUM_SEGS_P2: usize> { /* private fields */ }
Blocking producer for unbounded SPSC queue.

Implementations

Source

impl<T, const P: usize, const NUM_SEGS_P2: usize> BlockingUnboundedSpscProducer<T, P, NUM_SEGS_P2>

pub fn try_send(&self, value: T) -> Result<(), PushError<T>>

Fast-path send without blocking.

For unbounded queues, this always succeeds unless the channel is closed.

pub fn send(&self, value: T) -> Result<(), PushError<T>>

Sends a single item.

For unbounded queues, this never blocks since the queue grows dynamically.

pub fn send_slice(&self, values: &mut Vec<T>) -> Result<(), PushError<()>>

Sends a Vec of items using bulk operations.

On return, the Vec will be empty if all items were sent, or contain only the items that were not sent (if the channel closed).

pub fn close(&mut self)

Closes the queue and wakes any waiters.

pub fn node_count(&self) -> usize

Returns the number of nodes in the unbounded queue.

pub fn total_capacity(&self) -> usize

Returns the total capacity across all nodes.