Structs
- Timer
Batch - Batch of scheduling requests.
- Timer
Schedule - Remote scheduling request for a timer.
- Wait
Strategy - Wake
Stats - Worker
- Worker
Health Snapshot - Health snapshot of a worker at a point in time. Used by the supervisor for health monitoring and load balancing decisions.
- Worker
Service - Worker
Service Config - Worker
Stats - Comprehensive statistics for fast worker.
- WorkerTLS
Enums
- Worker
Message - Worker control-plane messages.
Functions
- cancel_
timer_ for_ current_ task - Cancels a timer owned by the task currently being polled by the active worker.
- current_
task - current_
timer_ wheel - current_
worker_ now_ ns - Returns the most recent
now_nsobserved by the active worker. - is_
worker_ thread - pin_
current_ generator - Request that the current generator be pinned to the current task.
- schedule_
timer_ for_ current_ task - Schedules a timer for the task currently being polled by the active worker.