pub struct CachePadded<T> { /* private fields */ }Expand description
Pads and aligns a value to the length of a cache line.
In concurrent programming, sometimes it is desirable to make sure commonly accessed pieces of
data are not placed into the same cache line. Updating an atomic value invalidates the whole
cache line it belongs to, which makes the next access to the same cache line slower for other
CPU cores. Use CachePadded to ensure updating one piece of data doesn’t invalidate other
cached data.
Size and alignment
Cache lines are assumed to be N bytes long, depending on the architecture:
- On x86-64, aarch64, and powerpc64, N = 128.
- On arm, mips, mips64, sparc, and hexagon, N = 32.
- On m68k, N = 16.
- On s390x, N = 256.
- On all others, N = 64.
Note that N is just a reasonable guess and is not guaranteed to match the actual cache line length of the machine the program is running on. On modern Intel architectures, spatial prefetcher is pulling pairs of 64-byte cache lines at a time, so we pessimistically assume that cache lines are 128 bytes long.
The size of CachePadded<T> is the smallest multiple of N bytes large enough to accommodate
a value of type T.
The alignment of CachePadded<T> is the maximum of N bytes and the alignment of T.
Implementations
Sourceimpl<T> CachePadded<T>
impl<T> CachePadded<T>
Sourcepub const fn new(t: T) -> CachePadded<T>
pub const fn new(t: T) -> CachePadded<T>
Pads and aligns a value to the length of a cache line.
Sourcepub fn into_inner(self) -> T
pub fn into_inner(self) -> T
Returns the inner value.